Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/better_dedent/__init__.py | (no class) | 38 | 0 | 0 | 12 | 1 | 98%
tests/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
tests/test_better_dedent.py | TestDedentWithRegularStrings | 26 | 0 | 0 | 0 | 0 | 100%
tests/test_better_dedent.py | TestDedentWithTStrings | 52 | 0 | 0 | 0 | 0 | 100%
tests/test_better_dedent.py | TestUndent | 22 | 0 | 0 | 0 | 0 | 100%
tests/test_better_dedent.py | TestConvertHelper | 8 | 0 | 0 | 0 | 0 | 100%
tests/test_better_dedent.py | TestEdgeCases | 36 | 0 | 0 | 0 | 0 | 100%
tests/test_better_dedent.py | TestPropertyBasedTests | 4 | 0 | 0 | 0 | 0 | 100%
tests/test_better_dedent.py | (no class) | 58 | 0 | 0 | 0 | 0 | 100%
Total |  | 244 | 0 | 0 | 12 | 1 | 99%

No items found using the specified filter.